@@ -6,7 +6,7 @@ from .registering import register_plotly_resampler, unregister_plotly_resampler
 
 __docformat__ = "numpy"
 __author__ = "Jonas Van Der Donckt, Jeroen Van Der Donckt, Emiel Deprost"
-__version__ = "0.7.2.1"
+__version__ = "0.8.1"
 
 __all__ = [
     "__version__",
@@ -27,5 +27,5 @@ try:  # Enable ipywidgets on google colab!
         from google.colab import output
 
         output.enable_custom_widget_manager()
-except ImportError:
+except (ImportError, ModuleNotFoundError):
     pass
